Module cuda
nvfbc
0.2.0
Module cuda
Module Items
Structs
Enums
In crate nvfbc
nvfbc
Module
cuda
Structs

Cuda
Capturer
Uses NVFBC to capture frames in the form of a CUDA device pointer.
Cuda
Frame
Info
Contains information about a frame captured in a CUDA device.
Enums

Capture
Method