CaptureMethod

Enum CaptureMethod 

pub enum CaptureMethod {
    NoWait = 1,
    NoWaitIfNewFrame = 4,
    Blocking = 0,
}

Variants



NoWait = 1

Capturing does not wait for a new frame nor a mouse move.

It is therefore possible to capture the same frame multiple times. When this occurs, the current_frame parameter of the CudaFrameInfo struct is not incremented.



NoWaitIfNewFrame = 4

Similar to NoWait, except that the capture will not wait if there is already a frame available that the client has never seen yet.



Blocking = 0

Capturing waits for a new frame or mouse move.